@@ -39,11 +39,11 @@ from .exc import InvalidGitRepositoryError
 # Handle once test-cases are back up and running.
 # Most of these are unused here, but are for use by git-python modules so these
 # don't see gitdb all the time. Flake of course doesn't like it.
-__all__ = ("stream_copy", "join_path", "to_native_path_windows", "to_native_path_linux",
+__all__ = ["stream_copy", "join_path", "to_native_path_linux",
            "join_path_native", "Stats", "IndexFileSHA1Writer", "Iterable", "IterableList",
            "BlockingLockFile", "LockFile", 'Actor', 'get_user_id', 'assure_directory_exists',
            'RemoteProgress', 'CallableRemoteProgress', 'rmtree', 'unbare_repo',
-           'HIDE_WINDOWS_KNOWN_ERRORS')
+           'HIDE_WINDOWS_KNOWN_ERRORS']
 
 log = logging.getLogger(__name__)
 
@@ -94,7 +94,7 @@ def rmtree(path):
             func(path)  # Will scream if still not possible to delete.
         except Exception as ex:
             if HIDE_WINDOWS_KNOWN_ERRORS:
-                raise SkipTest("FIXME: fails with: PermissionError\n  {}".format(ex))
+                raise SkipTest("FIXME: fails with: PermissionError\n  {}".format(ex)) from ex
             raise
 
     return shutil.rmtree(path, False, onerror)
@@ -148,6 +148,7 @@ if is_win:
     def to_native_path_linux(path):
         return path.replace('\\', '/')
 
+    __all__.append("to_native_path_windows")
     to_native_path = to_native_path_windows
 else:
     # no need for any work on linux
@@ -746,7 +747,7 @@ class LockFile(object):
             fd = os.open(lock_file, flags, 0)
             os.close(fd)
         except OSError as e:
-            raise IOError(str(e))
+            raise IOError(str(e)) from e
 
         self._owns_lock = True
 
@@ -801,19 +802,19 @@ class BlockingLockFile(LockFile):
         while True:
             try:
                 super(BlockingLockFile, self)._obtain_lock()
-            except IOError:
+            except IOError as e:
                 # synity check: if the directory leading to the lockfile is not
                 # readable anymore, raise an exception
                 curtime = time.time()
                 if not osp.isdir(osp.dirname(self._lock_file_path())):
                     msg = "Directory containing the lockfile %r was not readable anymore after waiting %g seconds" % (
                         self._lock_file_path(), curtime - starttime)
-                    raise IOError(msg)
+                    raise IOError(msg) from e
                 # END handle missing directory
 
                 if curtime >= maxtime:
                     msg = "Waited %g seconds for lock at %r" % (maxtime - starttime, self._lock_file_path())
-                    raise IOError(msg)
+                    raise IOError(msg) from e
                 # END abort if we wait too long
                 time.sleep(self._check_interval)
             else:
@@ -878,8 +879,8 @@ class IterableList(list):
 
         try:
             return getattr(self, index)
-        except AttributeError:
-            raise IndexError("No item found with id %r" % (self._prefix + index))
+        except AttributeError as e:
+            raise IndexError("No item found with id %r" % (self._prefix + index)) from e
         # END handle getattr
 
     def __delitem__(self, index):
